==> charmap_1.0.2.tar.gz: charmap-1.0.2/maemo-gucharmap-chartable.h <==
/*
 *  charmap - GTK+ based simple character map
 *
 *  Copyright (C) 2014 Peter Pichler (this application)
 *  Copyrught (C) 2010 Gabriel Schulhof (the author of scv-reader,
 *                     a Maemo package this app was partially based on)
 *  Copyright (C) 2010 The GNOME Charcter Map project (the icon)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to Free Software Foundation Inc.,
 *  59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef MAEMO_GUCHARMAP_CHARTABLE_H
#define MAEMO_GUCHARMAP_CHARTABLE_H

#include <glib-object.h>

G_BEGIN_DECLS

typedef struct _MaemoGucharmapChartable      MaemoGucharmapChartable;
typedef struct _MaemoGucharmapChartableClass MaemoGucharmapChartableClass;

GType maemo_gucharmap_chartable_get_type();

#define MAEMO_GUCHARMAP_CHARTABLE_TYPE (maemo_gucharmap_chartable_get_type())
#define MAEMO_GUCHARMAP_CHARTABLE(object)           (G_TYPE_CHECK_INSTANCE_CAST((object), MAEMO_GUCHARMAP_CHARTABLE_TYPE, MaemoGucharmapChartable))
#define MAEMO_GUCHARMAP_CHARTABLE_CLASS(klass)      (G_TYPE_CHECK_CLASS_CAST((klass),     MAEMO_GUCHARMAP_CHARTABLE_TYPE, MaemoGucharmapChartableClass))
#define IS_MAEMO_GUCHARMAP_CHARTABLE(object)        (G_TYPE_CHECK_INSTANCE_TYPE((object), MAEMO_GUCHARMAP_CHARTABLE_TYPE))
#define IS_MAEMO_GUCHARMAP_CHARTABLE_CLASS(klass)   (G_TYPE_CHECK_CLASS_TYPE((klass),     MAEMO_GUCHARMAP_CHARTABLE_TYPE))
#define MAEMO_GUCHARMAP_CHARTABLE_GET_CLASS(object) (G_TYPE_INSTANCE_GET_CLASS((object),  MAEMO_GUCHARMAP_CHARTABLE_TYPE, MaemoGucharmapChartableClass))

G_END_DECLS

#endif /* MAEMO_GUCHARMAP_CHARTABLE_H */

==> charmap_1.0.3.tar.gz: charmap-1.0.3/maemo-gucharmap-chartable.h <==
/*
 *  charmap - GTK+ based simple character map
 *
 *  Copyright (C) 2014 Peter Pichler (this application)
 *  Copyrught (C) 2010 Gabriel Schulhof (the author of scv-reader,
 *                     a Maemo package this app was partially based on)
 *  Copyright (C) 2010 The GNOME Charcter Map project (the icon)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to Free Software Foundation Inc.,
 *  59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef MAEMO_GUCHARMAP_CHARTABLE_H
#define MAEMO_GUCHARMAP_CHARTABLE_H

#include <glib-object.h>

G_BEGIN_DECLS

typedef struct _MaemoGucharmapChartable      MaemoGucharmapChartable;
typedef struct _MaemoGucharmapChartableClass MaemoGucharmapChartableClass;

GType maemo_gucharmap_chartable_get_type();

#define MAEMO_GUCHARMAP_CHARTABLE_TYPE (maemo_gucharmap_chartable_get_type())
#define MAEMO_GUCHARMAP_CHARTABLE(object)           (G_TYPE_CHECK_INSTANCE_CAST((object), MAEMO_GUCHARMAP_CHARTABLE_TYPE, MaemoGucharmapChartable))
#define MAEMO_GUCHARMAP_CHARTABLE_CLASS(klass)      (G_TYPE_CHECK_CLASS_CAST((klass),     MAEMO_GUCHARMAP_CHARTABLE_TYPE, MaemoGucharmapChartableClass))
#define IS_MAEMO_GUCHARMAP_CHARTABLE(object)        (G_TYPE_CHECK_INSTANCE_TYPE((object), MAEMO_GUCHARMAP_CHARTABLE_TYPE))
#define IS_MAEMO_GUCHARMAP_CHARTABLE_CLASS(klass)   (G_TYPE_CHECK_CLASS_TYPE((klass),     MAEMO_GUCHARMAP_CHARTABLE_TYPE))
#define MAEMO_GUCHARMAP_CHARTABLE_GET_CLASS(object) (G_TYPE_INSTANCE_GET_CLASS((object),  MAEMO_GUCHARMAP_CHARTABLE_TYPE, MaemoGucharmapChartableClass))

void maemo_gucharmap_chartable_set_font (MaemoGucharmapChartable *chart, const char *name, int size);
void maemo_gucharmap_chartable_set_scroll_adjustments (MaemoGucharmapChartable *chart, double size);

G_END_DECLS

#endif /* MAEMO_GUCHARMAP_CHARTABLE_H */
